====
Sync
====

The sync module provides functionality for bidirectional synchronization between local database and Pinboard.in.

BidirectionalSync
=================

.. autoclass:: pinboard_tools.sync.bidirectional.BidirectionalSync
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: pinboard_tools.sync.bidirectional.SyncDirection
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: pinboard_tools.sync.bidirectional.ConflictResolution
   :members:
   :undoc-members:
   :show-inheritance:

PinboardAPI
===========

.. autoclass:: pinboard_tools.sync.api.PinboardAPI
   :members:
   :undoc-members:
   :show-inheritance:

.. autoexception:: pinboard_tools.sync.api.PinboardAPIError
   :members:
   :undoc-members:
   :show-inheritance: